@@ -873,6 +873,12 @@ pref_window_page_initializer (PrefState *state,
 				 gnm_conf_get_core_gui_editing_launchpage,
 				 _("Use Launch Page"));
 
+	bool_pref_create_widget (gnm_conf_get_core_gui_editing_showcursor_node (),
+				 page, row++,
+				 gnm_conf_set_core_gui_editing_showcursor,
+				 gnm_conf_get_core_gui_editing_showcursor,
+				 _("Show the mouse cursor"));
+
 	gtk_widget_show_all (page);
 	return page;
 }
