@@ -153,8 +153,6 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 	SheetView *sv = sc->view;
 	Sheet *sheet = sv->sheet;
 	WBCGtk *wbcg = scg->wbcg;
-	WorkbookControl * wbc = scg_wbc(scg);
-	Workbook * wb = wb_control_get_workbook(wbc);
 	gboolean delayed_movement = FALSE;
 	gboolean jump_to_bounds = event->state & GDK_CONTROL_MASK;
 	gboolean is_enter = FALSE;
@@ -181,12 +179,13 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 	switch (event->keyval) {
 	case GDK_KEY_KP_Left:
 	case GDK_KEY_Left:
-		if (event->state & GDK_MOD1_MASK)
-			return TRUE; /* Alt is used for accelerators */
+		//Maemo5 specific: for kbd with 2 arrows
+		//if (event->state & GDK_MOD1_MASK)
+		//	return TRUE; /* Alt is used for accelerators */
 
-		if (event->state & SCROLL_LOCK_MASK)
+		/*if (event->state & SCROLL_LOCK_MASK)
 			scg_set_left_col (scg, pane->first.col - 1);
-		else if (transition_keys && jump_to_bounds) {
+		else */if (transition_keys && jump_to_bounds) {
 			delayed_movement = TRUE;
 			scg_queue_movement (scg, movefn,
 				-(pane->last_visible.col - pane->first.col),
@@ -198,12 +197,13 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 
 	case GDK_KEY_KP_Right:
 	case GDK_KEY_Right:
-		if (event->state & GDK_MOD1_MASK)
-			return TRUE; /* Alt is used for accelerators */
+		//Maemo5 specific: for kbd with 2 arrows
+		//if (event->state & GDK_MOD1_MASK)
+			//return TRUE; /* Alt is used for accelerators */
 
-		if (event->state & SCROLL_LOCK_MASK)
+		/*if (event->state & SCROLL_LOCK_MASK)
 			scg_set_left_col (scg, pane->first.col + 1);
-		else if (transition_keys && jump_to_bounds) {
+		else */if (transition_keys && jump_to_bounds) {
 			delayed_movement = TRUE;
 			scg_queue_movement (scg, movefn,
 				pane->last_visible.col - pane->first.col,
@@ -215,9 +215,10 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 
 	case GDK_KEY_KP_Up:
 	case GDK_KEY_Up:
-		if (event->state & SCROLL_LOCK_MASK)
+		//Maemo5 specific: for kbd with 2 arrows
+		/*if (event->state & SCROLL_LOCK_MASK)
 			scg_set_top_row (scg, pane->first.row - 1);
-		else if (transition_keys && jump_to_bounds) {
+		else */if (transition_keys && jump_to_bounds) {
 			delayed_movement = TRUE;
 			scg_queue_movement (scg, movefn,
 				-(pane->last_visible.row - pane->first.row),
@@ -249,10 +250,10 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 				break;
 			}
 		}
-
-		if (event->state & SCROLL_LOCK_MASK)
+		//Maemo5 specific: for kbd with 2 arrows
+		/*if (event->state & SCROLL_LOCK_MASK)
 			scg_set_top_row (scg, pane->first.row + 1);
-		else if (transition_keys && jump_to_bounds) {
+		else*/ if (transition_keys && jump_to_bounds) {
 			delayed_movement = TRUE;
 			scg_queue_movement (scg, movefn,
 					    pane->last_visible.row - pane->first.row,
@@ -263,19 +264,9 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 
 	case GDK_KEY_KP_Page_Up:
 	case GDK_KEY_Page_Up:
-		if ((event->state & GDK_CONTROL_MASK) != 0){
-			if ((event->state & GDK_SHIFT_MASK) != 0){
-				WorkbookSheetState * old_state = workbook_sheet_state_new(wb);
-				int old_pos = sheet->index_in_wb;
-
-				if (old_pos > 0){
-					workbook_sheet_move(sheet, -1);
-					cmd_reorganize_sheets (wbc, old_state, sheet);
-				}
-			} else {
-				gnm_notebook_prev_page (wbcg->bnotebook);
-			}
-		} else if ((event->state & GDK_MOD1_MASK) == 0) {
+		if ((event->state & GDK_CONTROL_MASK) != 0)
+			gnm_notebook_prev_page (wbcg->bnotebook);
+		else if ((event->state & GDK_MOD1_MASK) == 0) {
 			delayed_movement = TRUE;
 			scg_queue_movement (scg, movefn,
 					    -(pane->last_visible.row - pane->first.row),
@@ -290,21 +281,9 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 
 	case GDK_KEY_KP_Page_Down:
 	case GDK_KEY_Page_Down:
-
-		if ((event->state & GDK_CONTROL_MASK) != 0){
-			if ((event->state & GDK_SHIFT_MASK) != 0){
-				WorkbookSheetState * old_state = workbook_sheet_state_new(wb);
-				int num_sheets = workbook_sheet_count(wb);
-				gint old_pos = sheet->index_in_wb;
-
-				if (old_pos < num_sheets - 1){
-					workbook_sheet_move(sheet, 1);
-					cmd_reorganize_sheets (wbc, old_state, sheet);
-				}
-			} else {
-				gnm_notebook_next_page (wbcg->bnotebook);
-			}
-		} else if ((event->state & GDK_MOD1_MASK) == 0) {
+		if ((event->state & GDK_CONTROL_MASK) != 0)
+			gnm_notebook_next_page (wbcg->bnotebook);
+		else if ((event->state & GDK_MOD1_MASK) == 0) {
 			delayed_movement = TRUE;
 			scg_queue_movement (scg, movefn,
 					    pane->last_visible.row - pane->first.row,
@@ -399,15 +378,29 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 	 */
 	case GDK_KP_Enter:
 	case GDK_KEY_Return:
-		if (wbcg_is_editing (wbcg) &&
-		    (state == GDK_CONTROL_MASK ||
-		     state == (GDK_CONTROL_MASK|GDK_SHIFT_MASK) ||
-		     gnumeric_filter_modifiers (event->state) == GDK_MOD1_MASK))
-			/* Forward the keystroke to the input line */
-			return gtk_widget_event (
-				wbcg_get_entry_underlying (wbcg), (GdkEvent *) event);
+		if (!wbcg_is_editing (wbcg)) {
+			//if ((event->state & (GDK_MOD1_MASK|GDK_CONTROL_MASK)) != 0)
+			//	return FALSE;
+
+			/* If the character is not printable do not start editing */
+			if (event->length == 0)
+				return FALSE;
+
+			/* For Maemo changed third arg to FALSE in order to avoid bug */
+			blockArrows = TRUE;
+			if (!wbcg_edit_start (wbcg, FALSE, FALSE)){
+				return FALSE; /* attempt to edit failed */
+			}
+		}
+		//return gtk_widget_event(wbcg_get_entry_underlying(wbcg), (GdkEvent *) event);
 		is_enter = TRUE;
-		/* fall down */
+		//isEnterEdit = TRUE;
+		//break;
+		/* Special Maemo5 change */
+		if(isEnterEdit){
+			isEnterEdit = FALSE;
+			break;
+		}
 
 	case GDK_KEY_Tab:
 	case GDK_KEY_ISO_Left_Tab:
@@ -440,9 +433,9 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 				if (is_enter) {
 					horizontal = go_direction_is_horizontal (dir);
 					forward = go_direction_is_forward (dir);
-				} else if ((event->state & GDK_CONTROL_MASK) &&
+				} else if ((event->state & GDK_CONTROL_MASK) && 
 					   ((sc_sheet (sc))->sheet_objects != NULL)) {
-					scg_object_select_next
+					scg_object_select_next 
 						(scg, (event->state & GDK_SHIFT_MASK) != 0);
 					break;
 				}
@@ -487,16 +480,20 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *event,
 		/* fall through */
 
 	default:
+		blockArrows = FALSE;
 		if (!wbcg_is_editing (wbcg)) {
-			if ((event->state & (GDK_MOD1_MASK|GDK_CONTROL_MASK)) != 0)
-				return FALSE;
+			//if ((event->state & (GDK_MOD1_MASK|GDK_CONTROL_MASK)) != 0)
+			//	return FALSE;
 
 			/* If the character is not printable do not start editing */
 			if (event->length == 0)
 				return FALSE;
 
-			if (!wbcg_edit_start (wbcg, TRUE, TRUE))
+			/* For Maemo changed third arg to FALSE in order to avoid bug */
+			if (!wbcg_edit_start (wbcg, TRUE, FALSE)){
+				blockArrows=TRUE;
 				return FALSE; /* attempt to edit failed */
+			}
 		}
 		scg_rangesel_stop (scg, FALSE);
 
