@@ -32,6 +32,7 @@
 #include <atk/atkrelationset.h>
 #include <gdk/gdkkeysyms.h>
 
+
 #include <string.h>
 
 #define ERROR_INFO_MAX_LEVEL 9
@@ -214,7 +215,7 @@ static gint
 cb_keyed_dialog_keypress (GtkWidget *dialog, GdkEventKey *event,
 			  G_GNUC_UNUSED gpointer user)
 {
-	if (event->keyval == GDK_Escape) {
+	if (event->keyval == GDK_KEY_Escape) {
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		return TRUE;
 	}
@@ -452,7 +453,7 @@ gnumeric_popup_menu (GtkMenu *menu, GdkEventButton *event)
 
 	if (event)
 		gtk_menu_set_screen (menu,
-				     gdk_drawable_get_screen (event->window));
+				     gdk_window_get_screen (event->window));
 
 	g_signal_connect (G_OBJECT (menu),
 		"hide",
@@ -1205,13 +1206,24 @@ gnm_link_button_and_entry (GtkWidget *button, GtkWidget *entry)
 void
 gnm_widget_set_cursor (GtkWidget *w, GdkCursor *cursor)
 {
-	gdk_window_set_cursor (gtk_widget_get_window (w), cursor);
+	if(gnm_conf_get_core_gui_editing_showcursor())
+		gdk_window_set_cursor (gtk_widget_get_window (w), cursor);
+	else{
+		gchar bits[] = { 0 }; 
+		GdkColor color = { 0, 0, 0, 0 }; 
+		GdkPixmap *pixmap;
+		GdkCursor *cursor_empty;
+
+		pixmap = gdk_bitmap_create_from_data(NULL, bits, 1, 1); 
+		cursor_empty = gdk_cursor_new_from_pixmap(pixmap, pixmap, &color, &color, 0, 0); 
+		gdk_window_set_cursor (gtk_widget_get_window (w), cursor_empty);
+	}
 }
 
 void
 gnm_widget_set_cursor_type (GtkWidget *w, GdkCursorType ct)
 {
-	GdkDisplay *display = gdk_drawable_get_display (gtk_widget_get_window (w));
+	GdkDisplay *display = gtk_widget_get_display (w);
 	GdkCursor *cursor = gdk_cursor_new_for_display (display, ct);
 	gnm_widget_set_cursor (w, cursor);
 	gdk_cursor_unref (cursor);
