@@ -6,6 +6,7 @@
  *    Jody Goldberg 2000-2006	(jody@gnome.org)
  *    Miguel de Icaza 1999 (miguel@kernel.org)
  *    Andreas J. Guelzow 2007   (aguelzow@pyrshep.ca)
+ *  Copyright (C) 2007-2009 Morten Welinder (terra@gnome.org)
  */
 #include <gnumeric-config.h>
 #include "gnumeric.h"
@@ -52,11 +53,12 @@
  */
 
 static void
-print_cell_gtk (GnmCell const *cell, GnmStyle const *mstyle,
-	    cairo_t *context,
-	    double x1, double y1, double width, double height, double h_center)
+print_cell_gtk (GnmCell const *cell,
+		cairo_t *context,
+		double x1, double y1,
+		double width, double height, double h_center)
 {
-	GnmRenderedValue *rv = cell->rendered_value, *rv100 = NULL;
+	GnmRenderedValue *rv, *rv100 = NULL;
 	GOColor fore_color;
 	gint x, y;
 	Sheet *sheet = cell->base.sheet;
@@ -68,10 +70,7 @@ print_cell_gtk (GnmCell const *cell, GnmStyle const *mstyle,
 	height -= GNM_ROW_MARGIN + GNM_ROW_MARGIN + 1;
 	width  -= GNM_COL_MARGIN + GNM_COL_MARGIN + 1;
 
-	if (rv == NULL) {
-		gnm_cell_render_value ((GnmCell *)cell, TRUE);
-		rv = cell->rendered_value;
-	}
+	rv = gnm_cell_fetch_rendered_value (cell, TRUE);
 
 	/* Create a rendered value for printing */
 	if (sheet->last_zoom_factor_used != 1) {
@@ -79,9 +78,9 @@ print_cell_gtk (GnmCell const *cell, GnmStyle const *mstyle,
 		 * We're zoomed and we don't want printing to reflect that.
 		 */
 
-		rv100 = gnm_rendered_value_new ((GnmCell *)cell, mstyle,
-						rv->variable_width,
+		rv100 = gnm_rendered_value_new ((GnmCell *)cell,
 						pango_layout_get_context (rv->layout),
+						rv->variable_width,
 						1.0);
 		rv = rv100;
 	}
@@ -90,7 +89,6 @@ print_cell_gtk (GnmCell const *cell, GnmStyle const *mstyle,
 	   display.  */
 	rv->might_overflow = rv->numeric_overflow;
 
-
 	if (cell_calc_layout (cell, rv, -1,
 			      (int)(width * PANGO_SCALE / scale_h),
 			      (int)(height * PANGO_SCALE / scale_v),
@@ -99,7 +97,7 @@ print_cell_gtk (GnmCell const *cell, GnmStyle const *mstyle,
 
 		/* Clip the printed rectangle */
 		cairo_save (context);
-
+#ifndef G_OS_WIN32
 		if (!rv->rotation) {
 			/* We do not clip rotated cells.  */
 			cairo_new_path (context);
@@ -107,12 +105,10 @@ print_cell_gtk (GnmCell const *cell, GnmStyle const *mstyle,
 					 width + 1, height + 1);
 			cairo_clip (context);
 		}
-
+#endif
 		/* Set the font colour */
-		cairo_set_source_rgb (context,
-			 UINT_RGBA_R (fore_color) / 255.,
-			 UINT_RGBA_G (fore_color) / 255.,
-			 UINT_RGBA_B (fore_color) / 255.);
+		cairo_set_source_rgba (context,
+				       GO_COLOR_TO_CAIRO (fore_color));
 
 		cairo_translate (context, x1+0.5, y1);
 
@@ -127,8 +123,8 @@ print_cell_gtk (GnmCell const *cell, GnmStyle const *mstyle,
 			     lines;
 			     lines = lines->next, li++) {
 				cairo_save (context);
-				cairo_move_to (context, 
-					       PANGO_PIXELS (x + li->dx), 
+				cairo_move_to (context,
+					       PANGO_PIXELS (x + li->dx),
 					       PANGO_PIXELS (- y + li->dy));
 				cairo_rotate (context, rv->rotation * (-M_PI / 180));
 				pango_cairo_show_layout_line (context, lines->data);
@@ -160,10 +156,11 @@ print_rectangle_gtk (cairo_t *context,
 static void
 print_cell_background_gtk (cairo_t *context,
 		       GnmStyle const *style, int col, int row,
-		       float x, float y, float w, float h)
+		       double x, double y, double w, double h)
 {
 	if (gnumeric_background_set_gtk (style, context))
-		print_rectangle_gtk (context, x, y, w, h);
+		/* Remember api excludes the far pixels */
+		print_rectangle_gtk (context, x, y, w+0.2, h+0.2);
 	gnm_style_border_print_diag_gtk (style, context, x, y, x+w, y+h);
 }
 
@@ -181,7 +178,7 @@ print_merged_range_gtk (cairo_t *context,
 		    double start_x, double start_y,
 		    GnmRange const *view, GnmRange const *range)
 {
-	float l, r, t, b;
+	double l, r, t, b;
 	int last;
 	GnmCell  const *cell  = sheet_cell_get (sheet, range->start.col, range->start.row);
 	int const dir = sheet->text_is_rtl ? -1 : 1;
@@ -217,8 +214,7 @@ print_merged_range_gtk (cairo_t *context,
 	}
 
 	if (gnumeric_background_set_gtk (style, context))
-		/* Remember api excludes the far pixels */
-		print_rectangle_gtk (context, l, t, r-l+1, b-t+1);
+		print_rectangle_gtk (context, l, t, r-l+0.2, b-t+0.2);
 
 	if (range->start.col < view->start.col)
 		l -= dir * sheet_col_get_distance_pts (sheet,
@@ -240,10 +236,10 @@ print_merged_range_gtk (cairo_t *context,
 			row_calc_spans ((ColRowInfo *)ri, cell->pos.row, sheet);
 
 		if (sheet->text_is_rtl)
-			print_cell_gtk (cell, style, context,
+			print_cell_gtk (cell, context,
 				r, t, l - r, b - t, -1.);
 		else
-			print_cell_gtk (cell, style, context,
+			print_cell_gtk (cell, context,
 				l, t, r - l, b - t, -1.);
 	}
 	gnm_style_border_print_diag_gtk (style, context, l, t, r, b);
@@ -264,7 +260,7 @@ gnm_gtk_print_cell_range (cairo_t *context,
 {
 	ColRowInfo const *ri = NULL, *next_ri = NULL;
 	int const dir = sheet->text_is_rtl ? -1 : 1;
-	float const hscale = sheet->display_formulas ? 2 : 1; 
+	double const hscale = sheet->display_formulas ? 2 : 1;
 	int start_row, start_col, end_col, end_row;
 
 	GnmStyleRow sr, next_sr;
@@ -485,7 +481,7 @@ gnm_gtk_print_cell_range (cairo_t *context,
 				/* no need to draw blanks */
 				GnmCell const *cell = sheet_cell_get (sheet, col, row);
 				if (!gnm_cell_is_empty (cell))
-					print_cell_gtk (cell, style, context, x, y,
+					print_cell_gtk (cell, context, x, y,
 							ci->size_pts * hscale,
 							ri->size_pts, -1.);
 
@@ -531,7 +527,7 @@ gnm_gtk_print_cell_range (cairo_t *context,
 						real_x -= offset;
 				}
 
-				print_cell_gtk (cell, style, context,
+				print_cell_gtk (cell, context,
 						real_x, y, tmp_width, ri->size_pts,
 						center_offset);
 			} else if (col != span->left)
