@@ -6,16 +6,18 @@
 #include "colrow.h"
 #include "position.h"
 #include <pango/pango.h>
-#include <goffice/utils/go-undo.h>
+#include <goffice/goffice.h>
+#include "libgnumeric.h"
 
 G_BEGIN_DECLS
 
+GNM_VAR_DECL Sheet *invalid_sheet;
+
+struct _GnmSheetSize {
+	int max_cols, max_rows;
+};
+
 typedef struct _SheetPrivate SheetPrivate;
-typedef enum {
-	GNM_SHEET_DATA,
-	GNM_SHEET_OBJECT,
-	GNM_SHEET_XLM
-} GnmSheetType;
 GType gnm_sheet_type_get_type (void);
 #define GNM_SHEET_TYPE_TYPE (gnm_sheet_type_get_type ())
 
@@ -47,7 +49,9 @@ struct _Sheet {
 
 	GnmNamedExprCollection *names;
 
+	/* This should eventually be moved to the views.  */
 	double      last_zoom_factor_used;
+	GnmRenderedValueCollection *rendered_values;
 
 	GSList      *sheet_objects;	/* List of objects in this sheet */
 	GnmCellPos   max_object_extent;
@@ -87,13 +91,15 @@ struct _Sheet {
 
 	gboolean    has_filtered_rows;
 
-        SolverParameters *solver_parameters;
+        GnmSolverParameters *solver_parameters;
 	GList            *scenarios;
+	GHashTable       *sort_setups;
 
 	gint simulation_round;
 
 	GnmDepContainer *deps;
 
+	GSList		 *slicers;
 	GSList		 *filters;
 	GSList		 *list_merged;
 	GHashTable	 *hash_merged;
@@ -103,14 +109,10 @@ struct _Sheet {
 	GnmColor	 *tab_text_color;
 	GnmSheetType	  sheet_type;
 
-	/* This needs to move elsewhere and get shared.  */
-	PangoContext *context;
+	GnmSheetSize size;
 
-	/* Size related data */
-	int max_rows, max_cols;
 	/* tile related data */
 	int tile_top_level, max_width, max_height;
-	gboolean partial_row, partial_col;
 };
 
 #define GNM_SHEET_TYPE	(gnm_sheet_get_type ())
@@ -128,10 +130,14 @@ void      sheet_destroy_contents (Sheet *sheet);
 gboolean  gnm_sheet_valid_size   (int cols, int rows);
 void      gnm_sheet_suggest_size (int *cols, int *rows);
 
-GOUndo   *gnm_sheet_resize       (Sheet *sheet, int cols, int rows, GOCmdContext *cc);
+GOUndo   *gnm_sheet_resize       (Sheet *sheet, int cols, int rows,
+				  GOCmdContext *cc, gboolean *perr);
 
-int gnm_sheet_get_max_rows (Sheet const *sheet);
-int gnm_sheet_get_max_cols (Sheet const *sheet);
+GnmSheetSize const *gnm_sheet_get_size (Sheet const *sheet);
+GnmSheetSize const *gnm_sheet_get_size2 (Sheet const *sheet,
+					 Workbook const *wb);
+#define gnm_sheet_get_max_rows(sheet) (gnm_sheet_get_size(sheet)->max_rows)
+#define gnm_sheet_get_max_cols(sheet) (gnm_sheet_get_size(sheet)->max_cols)
 #define gnm_sheet_get_last_col(sheet) (gnm_sheet_get_max_cols(sheet) - 1)
 #define gnm_sheet_get_last_row(sheet) (gnm_sheet_get_max_rows(sheet) - 1)
 
@@ -162,8 +168,8 @@ GPtrArray  *sheet_cells          (Sheet *sheet, gboolean comments);
 
 void        sheet_recompute_spans_for_col     (Sheet *sheet, int col);
 
-gboolean    sheet_is_region_empty 	      (Sheet *sheet, GnmRange const *r);
-gboolean    sheet_is_cell_empty 	      (Sheet *sheet, int col, int row);
+gboolean    sheet_is_region_empty	      (Sheet *sheet, GnmRange const *r);
+gboolean    sheet_is_cell_empty		      (Sheet *sheet, int col, int row);
 
 gboolean    sheet_col_is_hidden		   (Sheet const *sheet, int col);
 gboolean    sheet_row_is_hidden		   (Sheet const *sheet, int row);
@@ -181,6 +187,8 @@ int	    sheet_find_boundary_vertical   (Sheet *sheet, int move_col, int row,
 ColRowInfo const *sheet_colrow_get_default (Sheet const *sheet,
 					    gboolean is_cols);
 
+void        sheet_colrow_optimize          (Sheet *sheet);
+
 /* Returns a pointer to a ColRowInfo: existing or NULL */
 ColRowInfo *sheet_col_get                 (Sheet const *sheet, int col);
 ColRowInfo *sheet_row_get                 (Sheet const *sheet, int row);
@@ -248,7 +256,7 @@ gboolean sheet_colrow_can_group	     (Sheet *sheet, GnmRange const *r,
 				      gboolean is_cols);
 gboolean sheet_colrow_group_ungroup  (Sheet *sheet, GnmRange const *r,
 				      gboolean is_cols, gboolean inc);
-void     sheet_colrow_gutter 	     (Sheet *sheet,
+void     sheet_colrow_gutter	     (Sheet *sheet,
 				      gboolean is_cols, int max_outline);
 
 gboolean sheet_range_splits_array    (Sheet const *sheet,
@@ -270,6 +278,16 @@ gboolean sheet_range_has_heading     (Sheet const *sheet, GnmRange const *src,
 
 void gnm_sheet_foreach_name (Sheet const *sheet, GHFunc func, gpointer data);
 
+void gnm_sheet_set_solver_params (Sheet *sheet, GnmSolverParameters *param);
+
+GnmScenario *gnm_sheet_scenario_new (Sheet *sheet, const char *name);
+GnmScenario *gnm_sheet_scenario_find (Sheet *sheet, const char *name);
+void gnm_sheet_scenario_add (Sheet *sheet, GnmScenario *sc);
+void gnm_sheet_scenario_remove (Sheet *sheet, GnmScenario *sc);
+
+GHashTable *gnm_sheet_get_sort_setups (Sheet *sheet);
+void gnm_sheet_add_sort_setup (Sheet *sheet, char *key, gpointer setup);
+gconstpointer gnm_sheet_find_sort_setup (Sheet *sheet, char const *key);
 
 /* Redraw */
 #define sheet_is_visible(_sheet) ((_sheet)->visibility == GNM_SHEET_VISIBILITY_VISIBLE)
@@ -291,10 +309,11 @@ void	 sheet_scrollbar_config		(Sheet const *s);
 void     sheet_mark_dirty	(Sheet *sheet);
 GnmRange    sheet_get_extent	(Sheet const *sheet,
 				 gboolean spans_and_merges_extend);
+GnmRange    sheet_get_cells_extent (Sheet const *sheet);
 GnmRange    sheet_get_printarea	(Sheet const *sheet,
 				 gboolean include_styles,
 				 gboolean ignore_printarea);
-GnmRange    sheet_get_nominal_printarea	(Sheet const *sheet);
+GnmRange    *sheet_get_nominal_printarea (Sheet const *sheet);
 
 /*
  * Utilities to set cell contents, queueing recalcs,
@@ -306,8 +325,17 @@ void	     sheet_cell_set_value   (GnmCell *cell, GnmValue *v);
 void	     sheet_cell_set_text    (GnmCell *cell, char const *str,
 				     PangoAttrList *markup);
 GnmValue const *sheet_cell_get_value(Sheet *sheet, int col, int row);
-void	     sheet_range_set_text   (GnmParsePos const *pos, GnmRange const *r, char const *str);
+void	     sheet_range_set_text   (GnmParsePos const *pos,
+				     GnmRange const *r, char const *str);
+GOUndo *     sheet_range_set_text_undo (GnmSheetRange *sr,
+					char const *text);
+GOUndo *     sheet_range_set_expr_undo (GnmSheetRange *sr,
+					GnmExprTop const  *texpr);
+GOUndo *     sheet_range_set_markup_undo (GnmSheetRange *sr,
+					  PangoAttrList *markup);
 void	     sheet_apply_style	    (Sheet  *sheet, GnmRange const *range, GnmStyle *mstyle);
+GOUndo *     sheet_apply_style_undo (GnmSheetRange *sr,
+				     GnmStyle      *style);
 void	     sheet_apply_border	    (Sheet  *sheet, GnmRange const *range, GnmBorder **borders);
 void	     sheet_queue_respan     (Sheet const *sheet, int start_row, int end_row);
 void	     sheet_range_calc_spans (Sheet *sheet, GnmRange const *r, GnmSpanCalcFlags flags);
@@ -337,7 +365,8 @@ typedef enum {
 	CLEAR_NORESPAN	   = 0x10,
 	CLEAR_RECALC_DEPS  = 0x20,
 	CLEAR_MERGES	   = 0x40,
-	CLEAR_OBJECTS	   = 0x80
+	CLEAR_OBJECTS	   = 0x80,
+	CLEAR_FILTERED_ONLY = 0x100
 } SheetClearFlags;
 
 void  sheet_clear_region (Sheet *sheet,
@@ -345,6 +374,9 @@ void  sheet_clear_region (Sheet *sheet,
 			  int end_col, int end_row,
 			  int clear_flags, GOCmdContext *cc);
 
+GOUndo *sheet_clear_region_undo (GnmSheetRange *sr,
+				 int clear_flags);
+
 SheetView *sheet_get_view (Sheet const *sheet, WorkbookView const *wbv);
 
 #define SHEET_FOREACH_VIEW(sheet, view, code)					\
@@ -359,7 +391,7 @@ do {										\
 } while (0)
 
 #define SHEET_FOREACH_CONTROL(sheet, view, control, code)		\
-	SHEET_FOREACH_VIEW((sheet), view, 				\
+	SHEET_FOREACH_VIEW((sheet), view,				\
 		SHEET_VIEW_FOREACH_CONTROL(view, control, code);)
 
 /*
