@@ -164,7 +164,7 @@ wbcg_edit_finish (WBCGtk *wbcg, WBCEditResult result,
 		}
 		case (WBC_EDIT_ACCEPT_WO_AC):
 		case (WBC_EDIT_ACCEPT): {
-			GnmCell const *cell = sheet_cell_get
+			GnmCell const *cell = sheet_cell_get 
 				(sheet, sv->edit_pos.col, sv->edit_pos.row);
 			if (gnm_cell_is_nonsingleton_array (cell)) {
 				gnm_cmd_context_error_splits_array (GO_CMD_CONTEXT (wbc),
@@ -278,7 +278,7 @@ wbcg_edit_finish (WBCGtk *wbcg, WBCEditResult result,
 								   GTK_EDITABLE (wbcg_get_entry (wbcg)), -1);
 
 				reedit = wb_control_validation_msg (WORKBOOK_CONTROL (wbcg),
-								    VALIDATION_STYLE_PARSE_ERROR, NULL,
+								    VALIDATION_STYLE_PARSE_ERROR, NULL, 
 								    perr.err->message);
 				if (showed_dialog != NULL)
 					*showed_dialog = TRUE;
@@ -349,7 +349,7 @@ wbcg_edit_finish (WBCGtk *wbcg, WBCEditResult result,
 
 			u = go_undo_combine (u,  clipboard_copy_range_undo (sheet, r));
 			if (texpr) {
-				gnm_expr_top_ref (texpr);
+				gnm_expr_top_ref (texpr); 
 				gnm_cell_set_array_formula (sheet,
 							    r->start.col, r->start.row,
 							    r->end.col, r->end.row,
@@ -397,7 +397,7 @@ wbcg_edit_finish (WBCGtk *wbcg, WBCEditResult result,
 					(GtkWidget *) wbcg_get_entry (wbcg));
 				g_free (free_txt);
 				if (texpr != NULL)
-					gnm_expr_top_unref (texpr);
+					gnm_expr_top_unref (texpr); 
 				return FALSE;
 			}
 		} else {
@@ -419,7 +419,7 @@ wbcg_edit_finish (WBCGtk *wbcg, WBCEditResult result,
 			}
 		}
 		if (texpr != NULL)
-			gnm_expr_top_unref (texpr);
+			gnm_expr_top_unref (texpr); 
 		g_free (free_txt);
 	} else {
 		if (sv == wb_control_cur_sheet_view (wbc)) {
@@ -502,6 +502,7 @@ wbcg_edit_finish (WBCGtk *wbcg, WBCEditResult result,
 	wbcg_auto_complete_destroy (wbcg);
 	wb_control_style_feedback (wbc, NULL);	/* in case markup messed with things */
 
+	blockArrows = TRUE;
 	return TRUE;
 }
 
@@ -554,7 +555,7 @@ cb_entry_insert_text (GtkEditable *editable,
 	if (wbcg->auto_completing &&
 	    len_bytes != 0 &&
 	    (!g_unichar_isalpha (g_utf8_get_char (text)) ||
-	     *pos_in_chars != gtk_entry_get_text_length (GTK_ENTRY (editable)))) {
+	     *pos_in_chars != gtk_entry_get_text_length(GTK_ENTRY (editable)))) {
 		wbcg->auto_completing = FALSE;
 	}
 
@@ -626,7 +627,7 @@ cb_entry_cursor_pos (WBCGtk *wbcg)
 	if (str[0] == 0)
 		return;
 
-	if (edit_pos != gtk_entry_get_text_length (GTK_ENTRY (entry))) {
+	if (edit_pos != gtk_entry_get_text_length(GTK_ENTRY (entry))) {
 		/* The cursor is no longer at the end.  */
 		wbcg->auto_completing = FALSE;
 	}
@@ -880,6 +881,8 @@ wbcg_edit_start (WBCGtk *wbcg,
 
 	g_return_val_if_fail (IS_WBC_GTK (wbcg), FALSE);
 
+	isEnterEdit = TRUE;
+
 	if (wbcg_is_editing (wbcg))
 		return TRUE;
 
